import os


def create_mp(
    evaluator, func: str, ddl_dir: str = f"{os.getcwd()}/macros/snow-mask-ddl"
):
    ddl_file = f"{ddl_dir}/{func}.sql"
    func_parts = str(func).split(".")
    if len(func_parts) != 2:
        raise Exception("Function name must be 2 parts e.g. `schema.mp_name.sql`")

    schema = func_parts[0]
    with open(ddl_file, "r") as file:
        content = file.read()

    return ";".join(
        [f"CREATE SCHEMA IF NOT EXISTS {schema}", content.replace("@schema", schema)]
    )
    
    
def apply_mp(
    evaluator,
    model: str,
    column: str,
    func: str,
    conditional_columns=[],
    materialization: str = "TABLE",
):
    return """
        ALTER {materialization} {model}
        modify column {column}
        set masking policy {func} using ({conditional_columns}) force;
        """.format(
        materialization=materialization,
        model=model,
        column=column,
        func=func,
        conditional_columns=",".join([x.name for x in conditional_columns.expressions]),
    )
